# greet_anyone

An example library and cli to greet anyone.

## Usage

### CLI

```
usage: cli.py [-h] [--exited EXITED] who

Greet anyone.

positional arguments:
  who              who to greet

options:
  -h, --help       show this help message and exit
  --exited EXITED  adds a exclamation point at the end
```

#### Examples
```sh
greet_anyone Traveler --exited true
```

## Features
- Greet anyone